From a17cdc9877b918777a735eb656dfbc20ca77e4e1 Mon Sep 17 00:00:00 2001
From: Andrew Esh <andrew.esh@qterics.com>
Date: Tue, 17 Oct 2017 07:15:33 -0500
Subject: [PATCH 24/25] _common_ Add ArmHF architecture for Raspberry Pi

---
 cerbero/enums.py           | 3 ++-
 config/cross-lin-armhf.cbc | 8 ++++++++
 config/linux.config        | 9 ++++++---
 3 files changed, 16 insertions(+), 4 deletions(-)
 create mode 100644 config/cross-lin-armhf.cbc

diff --git a/cerbero/enums.py b/cerbero/enums.py
index 3bf7126..17a79ae 100644
--- a/cerbero/enums.py
+++ b/cerbero/enums.py
@@ -35,6 +35,7 @@ class Architecture:
     ARMv7 = 'armv7'
     ARMv7S = 'armv7s'
     ARM64 = 'arm64'
+    ARMHF = 'armhf'
 
     @staticmethod
     def is_arm(arch):
@@ -43,7 +44,7 @@ class Architecture:
         wish to do something special for 64bit you should first check for
         that before calling this method.'''
         return arch in [Architecture.ARM, Architecture.ARMv7,
-                Architecture.ARMv7S, Architecture.ARM64]
+                        Architecture.ARMv7S, Architecture.ARM64, Architecture.ARMHF]
 
 
 class Distro:
diff --git a/config/cross-lin-armhf.cbc b/config/cross-lin-armhf.cbc
new file mode 100644
index 0000000..808083e
--- /dev/null
+++ b/config/cross-lin-armhf.cbc
@@ -0,0 +1,8 @@
+import os
+from cerbero.config import Platform, Architecture, Distro, DistroVersion
+
+target_platform = Platform.LINUX
+target_distro = Distro.DEBIAN
+target_arch = Architecture.ARMHF
+variants = ['noalsa', 'nox11', 'nopulse', 'nocdparanoia', 'nosdl',
+            'nov4l2', 'notestspackage', 'nopython']
diff --git a/config/linux.config b/config/linux.config
index 6bb5e5b..4dfe84f 100644
--- a/config/linux.config
+++ b/config/linux.config
@@ -36,10 +36,13 @@ if target_arch == Architecture.X86:
 elif target_arch == Architecture.X86_64:
     arch_flags += ' -m64 '
     _host = 'x86_64-linux-gnu'
-if target_arch in [Architecture.ARM, Architecture.ARMv7]:
-    if target_arch == Architecture.ARMv7:
+if target_arch in [Architecture.ARM, Architecture.ARMv7, Architecture.ARMHF]:
+    if target_arch in [Architecture.ARMv7, Architecture.ARMHF]:
        arch_flags += ' -march=armv7-a '
-    _host = 'arm-linux-gnueabi'
+    if target_arch == Architecture.ARMHF:
+       _host = 'arm-linux-gnueabihf'
+    else:
+       _host = 'arm-linux-gnueabi'
     os.environ['glib_cv_stack_grows'] = 'no'
     os.environ['glib_cv_uscore'] = 'no'
     os.environ['ac_cv_func_posix_getgrgid_r'] = 'yes'
-- 
2.15.0

